/* modify.h: Prototypes and declarations for modify.c
 * Copyright (C) 2006 Julian Graham
 *
 * libRUIN is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * libRUIN is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with libRUIN; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */

#ifndef RUIN_HANDLERS_MODIFY_H
#define RUIN_HANDLERS_MODIFY_H

#include <libguile.h>

SCM ruin_scm_default_handler_attr_modified(SCM event);
SCM ruin_scm_default_handler_dom_node_inserted(SCM event);
SCM ruin_scm_default_handler_dom_node_removed(SCM event);

#endif
